@@ -135,7 +135,12 @@ class Workbook:
             if self.verbose:
                 print(f"EasyPyXL created sheet: {sheetname}")
         else:
-            if sheetname in self.workbook.sheetnames:
+            if sheetname is None:
+                sheet = self.workbook.active
+                sheetname = sheet.title
+                if self.verbose:
+                    print(f"EasyPyXL loaded active sheet: {sheetname}")
+            elif sheetname in self.workbook.sheetnames:
                 sheet = self.workbook[sheetname]
                 if self.verbose:
                     print(f"EasyPyXL loaded sheet: {sheetname}")
